package
Version:
v0.9.0
Opens a new window with list of versions in this module.
Published: May 22, 2026
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
var RegistryURL = "https://raw.githubusercontent.com/topxeq/xxaitk-scripts/main/registry.json"
type Library struct {
Name string `json:"name"`
Version string `json:"version"`
Author string `json:"author"`
Description string `json:"description"`
URL string `json:"url"`
Category string `json:"category"`
}
type Registry struct {
Libraries []Library `json:"libraries"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.